@@ -41,7 +41,7 @@ from numbers import Real
 # only two required files.
 try:
     from .version import Version
-    __version__ = str(Version(fpath=__file__, archive_commit="$Format:%h$", reponame="param"))
+    __version__ = str(Version(fpath=__file__, archive_commit="9123ba0e", reponame="param"))
 except:
     __version__ = "0.0.0+unknown"
 
@@ -54,6 +54,12 @@ try:
 except:
     pass
 
+
+try:
+    import collections.abc as collections_abc
+except ImportError:
+    collections_abc = collections
+
 if sys.version_info[0] >= 3:
     unicode = str
 
@@ -108,9 +114,9 @@ def hashable(x):
     part of the object has changed.  Does not (currently) recursively
     replace mutable subobjects.
     """
-    if isinstance(x, collections.MutableSequence):
+    if isinstance(x, collections_abc.MutableSequence):
         return tuple(x)
-    elif isinstance(x, collections.MutableMapping):
+    elif isinstance(x, collections_abc.MutableMapping):
         return tuple([(k,v) for k,v in x.items()])
     else:
         return x
@@ -1164,7 +1170,7 @@ class ObjectSelector(SelectorBase):
                  compute_default_fn=None,check_on_set=None,allow_None=None,**params):
         if objects is None:
             objects = []
-        if isinstance(objects, collections.Mapping):
+        if isinstance(objects, collections_abc.Mapping):
             self.names = objects
             self.objects = list(objects.values())
         else:
@@ -1286,7 +1292,7 @@ class Selector(ObjectSelector):
 
 class ClassSelector(SelectorBase):
     """
-    Parameter whose value is a specified class or an instance of that class.
+    Parameter allowing selection of either a subclass or an instance of a given set of classes.
     By default, requires an instance, but if is_instance=False, accepts a class instead.
     Both class and instance values respect the instantiate slot, though it matters only
     for is_instance=True.
@@ -1329,8 +1335,11 @@ class ClassSelector(SelectorBase):
         Only classes from modules that have been imported are added
         (see concrete_descendents()).
         """
-        classes = concrete_descendents(self.class_)
-        d=OrderedDict((name,class_) for name,class_ in classes.items())
+        classes = self.class_ if isinstance(self.class_, tuple) else (self.class_,)
+        all_classes = {}
+        for cls in classes:
+            all_classes.update(concrete_descendents(cls))
+        d=OrderedDict((name,class_) for name,class_ in all_classes.items())
         if self.allow_None:
             d['None']=None
         return d
@@ -1812,7 +1821,7 @@ class MultiFileSelector(ListSelector):
 
 class Date(Number):
     """
-    Date parameter of datetime type.
+    Date parameter of datetime or date type.
     """
 
     def __init__(self, default=None, **kwargs):
@@ -1827,10 +1836,35 @@ class Date(Number):
             return
 
         if not isinstance(val, dt_types) and not (self.allow_None and val is None):
-            raise ValueError("Date '%s' only takes datetime types."%self.name)
+            raise ValueError("Date '%s' only takes datetime and date types."%self.name)
 
         if self.step is not None and not isinstance(self.step, dt_types):
-            raise ValueError("Step parameter can only be None or a datetime type")
+            raise ValueError("Step parameter can only be None, a datetime or datetime type")
+
+        self._checkBounds(val)
+
+
+class CalendarDate(Number):
+    """
+    CalendarDate parameter of date type.
+    """
+
+    def __init__(self, default=None, **kwargs):
+        super(CalendarDate, self).__init__(default=default, **kwargs)
+
+    def _validate(self, val):
+        """
+        Checks that the value is numeric and that it is within the hard
+        bounds; if not, an exception is raised.
+        """
+        if self.allow_None and val is None:
+            return
+
+        if not isinstance(val, dt.date) and not (self.allow_None and val is None):
+            raise ValueError("CalendarDate '%s' only takes datetime types."%self.name)
+
+        if self.step is not None and not isinstance(self.step, dt.date):
+            raise ValueError("Step parameter can only be None or a date type")
 
         self._checkBounds(val)
 
@@ -1929,10 +1963,9 @@ class Range(NumericTuple):
 
 class DateRange(Range):
     """
-    A date range specified as (start_date, end_date).
+    A datetime or date range specified as (start, end).
 
-    Dates must be specified as datetime-like types (see
-    param.dt_types).
+    Bounds must be specified as datetime or date types (see param.dt_types).
     """
     def _validate(self, val):
         if self.allow_None and val is None:
@@ -1944,9 +1977,31 @@ class DateRange(Range):
 
         start, end = val
         if not end >= start:
-           raise ValueError("DateRange '%s': end date %s is before start date %s."%(self.name,val[1],val[0]))
+           raise ValueError("DateRange '%s': end datetime %s is before start datetime %s."%(self.name,val[1],val[0]))
 
         # Calling super(DateRange, self)._check(val) would also check
         # values are numeric, which is redundant, so just call
         # _checkBounds().
         self._checkBounds(val)
+
+
+class CalendarDateRange(Range):
+    """
+    A date range specified as (start_date, end_date).
+    """
+    def _validate(self, val):
+        if self.allow_None and val is None:
+            return
+
+        for n in val:
+            if not isinstance(n, dt.date):
+                raise ValueError("CalendarDateRange '%s' only takes date types: %s"%(self.name,val))
+
+        start, end = val
+        if not end >= start:
+           raise ValueError("CalendarDateRange '%s': end date %s is before start date %s."%(self.name,val[1],val[0]))
+
+        # Calling super(CalendarDateRange, self)._check(val) would also check
+        # values are numeric, which is redundant, so just call
+        # _checkBounds().
+        self._checkBounds(val)
